import sys


def fetch_value(mobile_no: str, password: str):
    import requests
    from bs4 import BeautifulSoup
    session = requests.Session()
    headers = {
        "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
        "Accept-Encoding": "gzip, deflate, br",
        "Accept-Language": "en-US,en;q=0.9",
        "Cache-Control": "max-age=0",
        "Connection": "keep-alive",
        "Host": "prepaidcs.com",
        "Upgrade-Insecure-Requests": "1",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/107.0.0.0 Safari/537.36"
    }

    session.headers = headers
    session.get("https://prepaidcs.com/login")
    payload = {'msisdn': mobile_no, 'password': password}
    session.post("https://prepaidcs.com/login_add", data=payload)
    session.headers = session.headers.update({"Referer": "https://prepaidcs.com/cardinformation"})
    res = session.get("https://prepaidcs.com/usage")

    gbRemain = float(BeautifulSoup(res.text, "html.parser").select("tr")[-1].select("td")[1].text.strip().split(" ")[0])
    return gbRemain

if __name__ == "__main__":
    mobile_no = sys.argv[1]
    password = sys.argv[2]
    print(f"{fetch_value(mobile_no, password)} GB")


from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='prepaidcsValueFetcher',
    version='0.0.2',
    description='prepaidcs value fetcher',
    py_modules=['prepaidcsValueFetcher'],
    package_dir={'': 'src'},
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/xh-dev-py/prepaidcsValueFetcher",
    author="xethhung",
    author_email="pypi@xethh.dev",
    install_requires=[
        "requests",
        "beautifulsoup4"
    ],
    extras_require={
        "dev": [
            "pytest>=3.7",
            "wheel==0.38.4",
            "twine==4.0.1",
        ]
    }
)
